.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xtensor_fixed
=============

Defined in ``xtensor/xfixed.hpp``

.. doxygenclass:: xt::xfixed_container
   :project: xtensor
   :members:

.. doxygentypedef:: xt::xtensor_fixed
   :project: xtensor

